# README #

A collection of useful functions and tools for working with gravitational waveform data.

Visit the [wiki](https://bitbucket.org/chadgalley/gwtools/wiki/Home)

# Install #

To install from pypi

```
>>> pip install gwtools
```

To install from source

```
>>> git clone git@bitbucket.org:chadgalley/gwtools.git
>>> pip install -e gwtools
```

where the "-e" installs an editable (development) project with pip. This allows
your local code edits to be automatically seen by the system-wide installation.
